@@ -31,6 +31,7 @@ class LibLynxAuthHTTPMiddleware(BaseHTTPMiddleware):
     async def authenticate(self, request):
         llid = request.cookies.get("llid")
         if llid:
+            logging.debug("Has cookie %s" % llid)
             try:
                 plain_cookie = base64.b64decode(llid.encode("utf8")).decode("utf8")
                 cookie_version, llid, ll_accountname, llid_sig = plain_cookie.split(
@@ -41,6 +42,8 @@ class LibLynxAuthHTTPMiddleware(BaseHTTPMiddleware):
                     llid.encode("utf8"),
                     digestmod="sha256",
                 ).hexdigest()
+                logging.debug("sig %s" % sig)
+                logging.debug("llid_sig %s" % llid_sig)
                 if sig == llid_sig:
                     return (
                         AuthCredentials(["authenticated"]),
@@ -48,8 +51,10 @@ class LibLynxAuthHTTPMiddleware(BaseHTTPMiddleware):
                     )
             except:
                 logging.debug("Cookie parsing in LibLynxAuthBackend caused exception",)
+                raise AuthenticationError("Cookie Parsing failed")
+
         identification = self.connect.new_identification(
-            request.client.host,
+            request.headers.get("X-Forwarded-For", request.client.host),
             str(URL(scope=request.scope)),
             request.headers.get("User-Agent", "<unknown>"),
         )
@@ -87,6 +92,7 @@ class LibLynxAuthHTTPMiddleware(BaseHTTPMiddleware):
                 response = RedirectResponse(url=exc.redirect_to)
             else:
                 response = PlainTextResponse(str(exc), status_code=400)
+                response.delete_cookie("llid")
 
         await response(scope, receive, send)
 
@@ -98,6 +104,7 @@ class LibLynxAuthHTTPMiddleware(BaseHTTPMiddleware):
                 request.user.account_id.encode("utf8"),
                 digestmod="sha256",
             ).hexdigest()
+            logging.debug("signed cookie sig %s" % sig)
             cookie = "2\n%s\n%s\n%s" % (
                 request.user.account_id,
                 request.user.username,
